from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.update_server_request_oauth_metadata_type_0_as_type_0 import (
        UpdateServerRequestOauthMetadataType0AsType0,
    )
    from ..models.update_server_request_oauth_metadata_type_0_resource_type_0 import (
        UpdateServerRequestOauthMetadataType0ResourceType0,
    )


T = TypeVar("T", bound="UpdateServerRequestOauthMetadataType0")


@_attrs_define
class UpdateServerRequestOauthMetadataType0:
    """
    Attributes:
        requires_authorization (bool | Unset):
        resource (None | Unset | UpdateServerRequestOauthMetadataType0ResourceType0):
        as_ (None | Unset | UpdateServerRequestOauthMetadataType0AsType0):
    """

    requires_authorization: bool | Unset = UNSET
    resource: None | Unset | UpdateServerRequestOauthMetadataType0ResourceType0 = UNSET
    as_: None | Unset | UpdateServerRequestOauthMetadataType0AsType0 = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.update_server_request_oauth_metadata_type_0_as_type_0 import (
            UpdateServerRequestOauthMetadataType0AsType0,
        )
        from ..models.update_server_request_oauth_metadata_type_0_resource_type_0 import (
            UpdateServerRequestOauthMetadataType0ResourceType0,
        )

        requires_authorization = self.requires_authorization

        resource: dict[str, Any] | None | Unset
        if isinstance(self.resource, Unset):
            resource = UNSET
        elif isinstance(self.resource, UpdateServerRequestOauthMetadataType0ResourceType0):
            resource = self.resource.to_dict()
        else:
            resource = self.resource

        as_: dict[str, Any] | None | Unset
        if isinstance(self.as_, Unset):
            as_ = UNSET
        elif isinstance(self.as_, UpdateServerRequestOauthMetadataType0AsType0):
            as_ = self.as_.to_dict()
        else:
            as_ = self.as_

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if requires_authorization is not UNSET:
            field_dict["requiresAuthorization"] = requires_authorization
        if resource is not UNSET:
            field_dict["resource"] = resource
        if as_ is not UNSET:
            field_dict["as"] = as_

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.update_server_request_oauth_metadata_type_0_as_type_0 import (
            UpdateServerRequestOauthMetadataType0AsType0,
        )
        from ..models.update_server_request_oauth_metadata_type_0_resource_type_0 import (
            UpdateServerRequestOauthMetadataType0ResourceType0,
        )

        d = dict(src_dict)
        requires_authorization = d.pop("requiresAuthorization", UNSET)

        def _parse_resource(data: object) -> None | Unset | UpdateServerRequestOauthMetadataType0ResourceType0:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                resource_type_0 = UpdateServerRequestOauthMetadataType0ResourceType0.from_dict(data)

                return resource_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(None | Unset | UpdateServerRequestOauthMetadataType0ResourceType0, data)

        resource = _parse_resource(d.pop("resource", UNSET))

        def _parse_as_(data: object) -> None | Unset | UpdateServerRequestOauthMetadataType0AsType0:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                as_type_0 = UpdateServerRequestOauthMetadataType0AsType0.from_dict(data)

                return as_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(None | Unset | UpdateServerRequestOauthMetadataType0AsType0, data)

        as_ = _parse_as_(d.pop("as", UNSET))

        update_server_request_oauth_metadata_type_0 = cls(
            requires_authorization=requires_authorization,
            resource=resource,
            as_=as_,
        )

        update_server_request_oauth_metadata_type_0.additional_properties = d
        return update_server_request_oauth_metadata_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.schema_35 import Schema35






T = TypeVar("T", bound="PostTeamsTeamIdMembersBody")



@_attrs_define
class PostTeamsTeamIdMembersBody:
    """ 
        Attributes:
            user_id (str):
            role (Schema35):
     """

    user_id: str
    role: Schema35
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        user_id = self.user_id

        role = self.role.value


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "userId": user_id,
            "role": role,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        user_id = d.pop("userId")

        role = Schema35(d.pop("role"))




        post_teams_team_id_members_body = cls(
            user_id=user_id,
            role=role,
        )


        post_teams_team_id_members_body.additional_properties = d
        return post_teams_team_id_members_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset







T = TypeVar("T", bound="GetSubscriptionResponseSubscriptionType0CardType0")



@_attrs_define
class GetSubscriptionResponseSubscriptionType0CardType0:
    """ 
        Attributes:
            valid (bool):
            brand (str):
            last4 (str):
            expires_year (float):
            expires_month (float):
     """

    valid: bool
    brand: str
    last4: str
    expires_year: float
    expires_month: float





    def to_dict(self) -> dict[str, Any]:
        valid = self.valid

        brand = self.brand

        last4 = self.last4

        expires_year = self.expires_year

        expires_month = self.expires_month


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "valid": valid,
            "brand": brand,
            "last4": last4,
            "expiresYear": expires_year,
            "expiresMonth": expires_month,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        valid = d.pop("valid")

        brand = d.pop("brand")

        last4 = d.pop("last4")

        expires_year = d.pop("expiresYear")

        expires_month = d.pop("expiresMonth")

        get_subscription_response_subscription_type_0_card_type_0 = cls(
            valid=valid,
            brand=brand,
            last4=last4,
            expires_year=expires_year,
            expires_month=expires_month,
        )

        return get_subscription_response_subscription_type_0_card_type_0




from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.server_file import ServerFile





T = TypeVar("T", bound="GetMcpServersServerSlugFilesResponse200")



@_attrs_define
class GetMcpServersServerSlugFilesResponse200:
    """ 
        Attributes:
            files (list[ServerFile]):
     """

    files: list[ServerFile]





    def to_dict(self) -> dict[str, Any]:
        from ..models.server_file import ServerFile
        files = []
        for files_item_data in self.files:
            files_item = files_item_data.to_dict()
            files.append(files_item)




        field_dict: dict[str, Any] = {}

        field_dict.update({
            "files": files,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.server_file import ServerFile
        d = dict(src_dict)
        files = []
        _files = d.pop("files")
        for files_item_data in (_files):
            files_item = ServerFile.from_dict(files_item_data)



            files.append(files_item)


        get_mcp_servers_server_slug_files_response_200 = cls(
            files=files,
        )

        return get_mcp_servers_server_slug_files_response_200




from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.server_tool_dto_annotations_type_0 import ServerToolDtoAnnotationsType0
    from ..models.server_tool_dto_output_schema_type_0 import ServerToolDtoOutputSchemaType0
    from ..models.server_tool_dto_schema import ServerToolDtoSchema


T = TypeVar("T", bound="ServerToolDto")


@_attrs_define
class ServerToolDto:
    """
    Attributes:
        tenant_id (str):
        server_id (float):
        tool_name (str):
        description (str):
        schema (ServerToolDtoSchema):
        output_schema (None | ServerToolDtoOutputSchemaType0):
        annotations (None | ServerToolDtoAnnotationsType0):
        is_enabled (bool):
    """

    tenant_id: str
    server_id: float
    tool_name: str
    description: str
    schema: ServerToolDtoSchema
    output_schema: None | ServerToolDtoOutputSchemaType0
    annotations: None | ServerToolDtoAnnotationsType0
    is_enabled: bool

    def to_dict(self) -> dict[str, Any]:
        from ..models.server_tool_dto_annotations_type_0 import ServerToolDtoAnnotationsType0
        from ..models.server_tool_dto_output_schema_type_0 import ServerToolDtoOutputSchemaType0

        tenant_id = self.tenant_id

        server_id = self.server_id

        tool_name = self.tool_name

        description = self.description

        schema = self.schema.to_dict()

        output_schema: dict[str, Any] | None
        if isinstance(self.output_schema, ServerToolDtoOutputSchemaType0):
            output_schema = self.output_schema.to_dict()
        else:
            output_schema = self.output_schema

        annotations: dict[str, Any] | None
        if isinstance(self.annotations, ServerToolDtoAnnotationsType0):
            annotations = self.annotations.to_dict()
        else:
            annotations = self.annotations

        is_enabled = self.is_enabled

        field_dict: dict[str, Any] = {}

        field_dict.update(
            {
                "tenantId": tenant_id,
                "serverId": server_id,
                "toolName": tool_name,
                "description": description,
                "schema": schema,
                "outputSchema": output_schema,
                "annotations": annotations,
                "isEnabled": is_enabled,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.server_tool_dto_annotations_type_0 import ServerToolDtoAnnotationsType0
        from ..models.server_tool_dto_output_schema_type_0 import ServerToolDtoOutputSchemaType0
        from ..models.server_tool_dto_schema import ServerToolDtoSchema

        d = dict(src_dict)
        tenant_id = d.pop("tenantId")

        server_id = d.pop("serverId")

        tool_name = d.pop("toolName")

        description = d.pop("description")

        schema = ServerToolDtoSchema.from_dict(d.pop("schema"))

        def _parse_output_schema(data: object) -> None | ServerToolDtoOutputSchemaType0:
            if data is None:
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                output_schema_type_0 = ServerToolDtoOutputSchemaType0.from_dict(data)

                return output_schema_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(None | ServerToolDtoOutputSchemaType0, data)

        output_schema = _parse_output_schema(d.pop("outputSchema"))

        def _parse_annotations(data: object) -> None | ServerToolDtoAnnotationsType0:
            if data is None:
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                annotations_type_0 = ServerToolDtoAnnotationsType0.from_dict(data)

                return annotations_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(None | ServerToolDtoAnnotationsType0, data)

        annotations = _parse_annotations(d.pop("annotations"))

        is_enabled = d.pop("isEnabled")

        server_tool_dto = cls(
            tenant_id=tenant_id,
            server_id=server_id,
            tool_name=tool_name,
            description=description,
            schema=schema,
            output_schema=output_schema,
            annotations=annotations,
            is_enabled=is_enabled,
        )

        return server_tool_dto



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.get_mcp_servers_server_slug_credentials_authorize_url_response_200_method import GetMcpServersServerSlugCredentialsAuthorizeUrlResponse200Method
from ..types import UNSET, Unset






T = TypeVar("T", bound="GetMcpServersServerSlugCredentialsAuthorizeUrlResponse200")



@_attrs_define
class GetMcpServersServerSlugCredentialsAuthorizeUrlResponse200:
    """ 
        Attributes:
            method (GetMcpServersServerSlugCredentialsAuthorizeUrlResponse200Method):
            url (str | Unset):
     """

    method: GetMcpServersServerSlugCredentialsAuthorizeUrlResponse200Method
    url: str | Unset = UNSET





    def to_dict(self) -> dict[str, Any]:
        method = self.method.value

        url = self.url


        field_dict: dict[str, Any] = {}

        field_dict.update({
            "method": method,
        })
        if url is not UNSET:
            field_dict["url"] = url

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        method = GetMcpServersServerSlugCredentialsAuthorizeUrlResponse200Method(d.pop("method"))




        url = d.pop("url", UNSET)

        get_mcp_servers_server_slug_credentials_authorize_url_response_200 = cls(
            method=method,
            url=url,
        )

        return get_mcp_servers_server_slug_credentials_authorize_url_response_200




from enum import Enum

class GetMcpServersServerSlugCredentialsAuthorizeUrlResponse200Method(str, Enum):
    APIKEY = "apikey"
    NONE = "none"
    OAUTH = "oauth"

    def __str__(self) -> str:
        return str(self.value)



"""Contains all the data models used in inputs/outputs"""

from .audit_log_response import AuditLogResponse
from .auth_metadata import AuthMetadata
from .auth_metadata_quota import AuthMetadataQuota
from .auth_metadata_quota_enabled_servers import AuthMetadataQuotaEnabledServers
from .auth_metadata_tenant import AuthMetadataTenant
from .auth_metadata_tenant_abilities import AuthMetadataTenantAbilities
from .auth_metadata_user import AuthMetadataUser
from .aws_secrets_manager_configuration import AwsSecretsManagerConfiguration
from .aws_secrets_manager_configuration_output import AwsSecretsManagerConfigurationOutput
from .azure_key_vault_configuration import AzureKeyVaultConfiguration
from .azure_key_vault_configuration_output import AzureKeyVaultConfigurationOutput
from .create_personal_access_token_request import CreatePersonalAccessTokenRequest
from .create_sandbox_response import CreateSandboxResponse
from .create_server_request import CreateServerRequest
from .create_server_request_transport_type import CreateServerRequestTransportType
from .create_user_request import CreateUserRequest
from .delete_mcp_servers_server_slug_credentials_response_200 import DeleteMcpServersServerSlugCredentialsResponse200
from .delete_mcp_servers_server_slug_members_member_type_member_id_response_200 import (
    DeleteMcpServersServerSlugMembersMemberTypeMemberIdResponse200,
)
from .delete_profiles_profile_id_claim_mappings_mapping_id_response_200 import (
    DeleteProfilesProfileIdClaimMappingsMappingIdResponse200,
)
from .delete_profiles_profile_id_response_200 import DeleteProfilesProfileIdResponse200
from .delete_sandboxes_sandbox_id_response_200 import DeleteSandboxesSandboxIdResponse200
from .delete_teams_team_id_claim_mappings_mapping_id_response_200 import (
    DeleteTeamsTeamIdClaimMappingsMappingIdResponse200,
)
from .delete_teams_team_id_invitations_invitation_id_response_200 import (
    DeleteTeamsTeamIdInvitationsInvitationIdResponse200,
)
from .delete_teams_team_id_members_user_id_response_200 import DeleteTeamsTeamIdMembersUserIdResponse200
from .delete_teams_team_id_response_200 import DeleteTeamsTeamIdResponse200
from .delete_users_user_sub_personal_access_tokens_pat_id_response_200 import (
    DeleteUsersUserSubPersonalAccessTokensPatIdResponse200,
)
from .delete_users_user_sub_response_200 import DeleteUsersUserSubResponse200
from .exec_command_body import ExecCommandBody
from .gcp_secret_manager_configuration import GcpSecretManagerConfiguration
from .gcp_secret_manager_configuration_output import GcpSecretManagerConfigurationOutput
from .get_mcp_servers_response_200 import GetMcpServersResponse200
from .get_mcp_servers_response_200_servers_item import GetMcpServersResponse200ServersItem
from .get_mcp_servers_response_200_servers_item_usage import GetMcpServersResponse200ServersItemUsage
from .get_mcp_servers_server_slug_credentials_authorize_url_redirect import (
    GetMcpServersServerSlugCredentialsAuthorizeUrlRedirect,
)
from .get_mcp_servers_server_slug_credentials_authorize_url_response_200 import (
    GetMcpServersServerSlugCredentialsAuthorizeUrlResponse200,
)
from .get_mcp_servers_server_slug_credentials_authorize_url_response_200_method import (
    GetMcpServersServerSlugCredentialsAuthorizeUrlResponse200Method,
)
from .get_mcp_servers_server_slug_credentials_authorize_url_return_to import (
    GetMcpServersServerSlugCredentialsAuthorizeUrlReturnTo,
)
from .get_mcp_servers_server_slug_credentials_profile_profile_id_apikeys_response_200 import (
    GetMcpServersServerSlugCredentialsProfileProfileIdApikeysResponse200,
)
from .get_mcp_servers_server_slug_credentials_profile_response_200 import (
    GetMcpServersServerSlugCredentialsProfileResponse200,
)
from .get_mcp_servers_server_slug_credentials_response_200 import GetMcpServersServerSlugCredentialsResponse200
from .get_mcp_servers_server_slug_credentials_server_apikeys_response_200 import (
    GetMcpServersServerSlugCredentialsServerApikeysResponse200,
)
from .get_mcp_servers_server_slug_credentials_server_response_200 import (
    GetMcpServersServerSlugCredentialsServerResponse200,
)
from .get_mcp_servers_server_slug_credentials_user_apikeys_response_200 import (
    GetMcpServersServerSlugCredentialsUserApikeysResponse200,
)
from .get_mcp_servers_server_slug_credentials_user_response_200 import GetMcpServersServerSlugCredentialsUserResponse200
from .get_mcp_servers_server_slug_files_response_200 import GetMcpServersServerSlugFilesResponse200
from .get_mcp_servers_server_slug_oauth_discover_response_200 import GetMcpServersServerSlugOauthDiscoverResponse200
from .get_mcp_servers_server_slug_tools_response_200 import GetMcpServersServerSlugToolsResponse200
from .get_members_response import GetMembersResponse
from .get_members_response_teams_item import GetMembersResponseTeamsItem
from .get_members_response_users_item import GetMembersResponseUsersItem
from .get_profiles_profile_id_claim_mappings_response_200 import GetProfilesProfileIdClaimMappingsResponse200
from .get_profiles_profile_id_response_200 import GetProfilesProfileIdResponse200
from .get_profiles_profile_id_tools_response_200 import GetProfilesProfileIdToolsResponse200
from .get_profiles_profile_id_tools_response_200_tools import GetProfilesProfileIdToolsResponse200Tools
from .get_profiles_response_200 import GetProfilesResponse200
from .get_sandbox_id_audit_logs_id_response_200 import GetSandboxIdAuditLogsIdResponse200
from .get_sandbox_id_audit_logs_id_response_200_pagination import GetSandboxIdAuditLogsIdResponse200Pagination
from .get_sandbox_response import GetSandboxResponse
from .get_subscription_response import GetSubscriptionResponse
from .get_subscription_response_subscription_type_0 import GetSubscriptionResponseSubscriptionType0
from .get_subscription_response_subscription_type_0_card_type_0 import GetSubscriptionResponseSubscriptionType0CardType0
from .get_teams_response_200 import GetTeamsResponse200
from .get_teams_team_id_claim_mappings_response_200 import GetTeamsTeamIdClaimMappingsResponse200
from .get_teams_team_id_invitations_response_200 import GetTeamsTeamIdInvitationsResponse200
from .get_teams_team_id_members_response_200 import GetTeamsTeamIdMembersResponse200
from .get_teams_team_id_members_response_200_members_item import GetTeamsTeamIdMembersResponse200MembersItem
from .get_teams_team_id_servers_response_200 import GetTeamsTeamIdServersResponse200
from .get_teams_team_id_servers_response_200_permissions_item import GetTeamsTeamIdServersResponse200PermissionsItem
from .get_tenants_tenant_id_response_200 import GetTenantsTenantIdResponse200
from .get_user_me_response import GetUserMeResponse
from .get_user_me_response_user import GetUserMeResponseUser
from .get_users_response_200 import GetUsersResponse200
from .get_users_type import GetUsersType
from .get_users_user_sub_personal_access_tokens_response_200 import GetUsersUserSubPersonalAccessTokensResponse200
from .hashi_corp_vault_configuration import HashiCorpVaultConfiguration
from .hashi_corp_vault_configuration_output import HashiCorpVaultConfigurationOutput
from .hosted_transport_config import HostedTransportConfig
from .hosted_transport_config_output import HostedTransportConfigOutput
from .hosted_transport_config_output_runtime import HostedTransportConfigOutputRuntime
from .http_streaming_transport_config import HttpStreamingTransportConfig
from .http_streaming_transport_config_output import HttpStreamingTransportConfigOutput
from .infisical_configuration import InfisicalConfiguration
from .infisical_configuration_output import InfisicalConfigurationOutput
from .list_sandboxes_response import ListSandboxesResponse
from .mcp_audit_log_verbosity import McpAuditLogVerbosity
from .patch_secret_stores_id_body import PatchSecretStoresIdBody
from .patch_secret_stores_store_id_mappings_mapping_name_body import PatchSecretStoresStoreIdMappingsMappingNameBody
from .patch_users_user_sub_personal_access_tokens_pat_id_response_200 import (
    PatchUsersUserSubPersonalAccessTokensPatIdResponse200,
)
from .personal_access_token import PersonalAccessToken
from .post_mcp_servers_server_slug_credentials_copy_response_200 import (
    PostMcpServersServerSlugCredentialsCopyResponse200,
)
from .post_mcp_servers_server_slug_files_response_200 import PostMcpServersServerSlugFilesResponse200
from .post_mcp_servers_server_slug_tools_tool_name_call_body import PostMcpServersServerSlugToolsToolNameCallBody
from .post_mcp_servers_server_slug_tools_tool_name_call_body_args import (
    PostMcpServersServerSlugToolsToolNameCallBodyArgs,
)
from .post_profiles_body import PostProfilesBody
from .post_profiles_profile_id_claim_mappings_body import PostProfilesProfileIdClaimMappingsBody
from .post_profiles_profile_id_claim_mappings_response_200 import PostProfilesProfileIdClaimMappingsResponse200
from .post_profiles_response_200 import PostProfilesResponse200
from .post_sandboxes_sandbox_id_write_file_response_200 import PostSandboxesSandboxIdWriteFileResponse200
from .post_secret_stores_body import PostSecretStoresBody
from .post_secret_stores_body_type import PostSecretStoresBodyType
from .post_secret_stores_store_id_mappings_body import PostSecretStoresStoreIdMappingsBody
from .post_teams_body import PostTeamsBody
from .post_teams_team_id_claim_mappings_body import PostTeamsTeamIdClaimMappingsBody
from .post_teams_team_id_claim_mappings_response_200 import PostTeamsTeamIdClaimMappingsResponse200
from .post_teams_team_id_invitations_body import PostTeamsTeamIdInvitationsBody
from .post_teams_team_id_invitations_response_200 import PostTeamsTeamIdInvitationsResponse200
from .post_teams_team_id_members_body import PostTeamsTeamIdMembersBody
from .post_teams_team_id_members_response_200 import PostTeamsTeamIdMembersResponse200
from .post_users_user_sub_personal_access_tokens_response_200 import PostUsersUserSubPersonalAccessTokensResponse200
from .profile import Profile
from .profile_claim_mapping import ProfileClaimMapping
from .profile_details_dto import ProfileDetailsDto
from .profile_details_dto_servers_item import ProfileDetailsDtoServersItem
from .put_mcp_servers_server_slug_authorization_body import PutMcpServersServerSlugAuthorizationBody
from .put_mcp_servers_server_slug_config_body_type_0 import PutMcpServersServerSlugConfigBodyType0
from .put_mcp_servers_server_slug_config_body_type_1 import PutMcpServersServerSlugConfigBodyType1
from .put_mcp_servers_server_slug_config_body_type_2 import PutMcpServersServerSlugConfigBodyType2
from .put_mcp_servers_server_slug_config_body_type_3 import PutMcpServersServerSlugConfigBodyType3
from .put_mcp_servers_server_slug_config_body_type_4 import PutMcpServersServerSlugConfigBodyType4
from .put_mcp_servers_server_slug_credentials_profiles_profile_id_response_200 import (
    PutMcpServersServerSlugCredentialsProfilesProfileIdResponse200,
)
from .put_mcp_servers_server_slug_credentials_server_response_200 import (
    PutMcpServersServerSlugCredentialsServerResponse200,
)
from .put_mcp_servers_server_slug_credentials_user_response_200 import PutMcpServersServerSlugCredentialsUserResponse200
from .put_mcp_servers_server_slug_files_file_id_name_body import PutMcpServersServerSlugFilesFileIdNameBody
from .put_mcp_servers_server_slug_files_file_id_name_response_200 import (
    PutMcpServersServerSlugFilesFileIdNameResponse200,
)
from .put_mcp_servers_server_slug_files_file_id_response_200 import PutMcpServersServerSlugFilesFileIdResponse200
from .put_mcp_servers_server_slug_is_enabled_body import PutMcpServersServerSlugIsEnabledBody
from .put_mcp_servers_server_slug_is_enabled_response_200 import PutMcpServersServerSlugIsEnabledResponse200
from .put_mcp_servers_server_slug_members_member_type_member_id_body import (
    PutMcpServersServerSlugMembersMemberTypeMemberIdBody,
)
from .put_mcp_servers_server_slug_members_member_type_member_id_body_role import (
    PutMcpServersServerSlugMembersMemberTypeMemberIdBodyRole,
)
from .put_mcp_servers_server_slug_members_member_type_member_id_response_200 import (
    PutMcpServersServerSlugMembersMemberTypeMemberIdResponse200,
)
from .put_mcp_servers_server_slug_source_code_body import PutMcpServersServerSlugSourceCodeBody
from .put_profiles_profile_id_body import PutProfilesProfileIdBody
from .put_profiles_profile_id_response_200 import PutProfilesProfileIdResponse200
from .put_profiles_profile_id_servers_server_slug_tools_body import PutProfilesProfileIdServersServerSlugToolsBody
from .put_profiles_profile_id_servers_server_slug_tools_response_200 import (
    PutProfilesProfileIdServersServerSlugToolsResponse200,
)
from .put_teams_team_id_body import PutTeamsTeamIdBody
from .put_teams_team_id_members_user_id_body import PutTeamsTeamIdMembersUserIdBody
from .put_teams_team_id_members_user_id_response_200 import PutTeamsTeamIdMembersUserIdResponse200
from .put_users_me_response_200 import PutUsersMeResponse200
from .sandbox_audit_log import SandboxAuditLog
from .sandbox_audit_log_details import SandboxAuditLogDetails
from .sandbox_dto import SandboxDto
from .sandbox_with_status_dto import SandboxWithStatusDto
from .sandbox_with_status_dto_status import SandboxWithStatusDtoStatus
from .schema_0 import Schema0
from .schema_4 import Schema4
from .schema_11 import Schema11
from .schema_17 import Schema17
from .schema_25 import Schema25
from .schema_29 import Schema29
from .schema_32 import Schema32
from .schema_35 import Schema35
from .schema_40 import Schema40
from .schema_50 import Schema50
from .schema_57_type_3 import Schema57Type3
from .schema_64 import Schema64
from .schema_65 import Schema65
from .schema_66 import Schema66
from .schema_67 import Schema67
from .schema_68 import Schema68
from .schema_69 import Schema69
from .schema_76 import Schema76
from .secret_mapping_list_response import SecretMappingListResponse
from .secret_mapping_response import SecretMappingResponse
from .secret_store_detail_response import SecretStoreDetailResponse
from .secret_store_list_response import SecretStoreListResponse
from .secret_store_response import SecretStoreResponse
from .send_verification_code_request import SendVerificationCodeRequest
from .send_verification_code_request_purpose import SendVerificationCodeRequestPurpose
from .send_verification_code_response import SendVerificationCodeResponse
from .server import Server
from .server_authorization import ServerAuthorization
from .server_authorization_output import ServerAuthorizationOutput
from .server_authorization_output_method import ServerAuthorizationOutputMethod
from .server_credentials_api_keys import ServerCredentialsApiKeys
from .server_credentials_dto import ServerCredentialsDto
from .server_credentials_dto_type import ServerCredentialsDtoType
from .server_credentials_outh import ServerCredentialsOuth
from .server_credentials_outh_token_set import ServerCredentialsOuthTokenSet
from .server_dto import ServerDto
from .server_file import ServerFile
from .server_member_type_0 import ServerMemberType0
from .server_member_type_1 import ServerMemberType1
from .server_o_auth_client_configuration import ServerOAuthClientConfiguration
from .server_o_auth_client_configuration_grant_type import ServerOAuthClientConfigurationGrantType
from .server_o_auth_metadata import ServerOAuthMetadata
from .server_o_auth_metadata_as import ServerOAuthMetadataAs
from .server_o_auth_metadata_resource import ServerOAuthMetadataResource
from .server_pod_status import ServerPodStatus
from .server_running_status_response import ServerRunningStatusResponse
from .server_tool_dto import ServerToolDto
from .server_tool_dto_annotations_type_0 import ServerToolDtoAnnotationsType0
from .server_tool_dto_output_schema_type_0 import ServerToolDtoOutputSchemaType0
from .server_tool_dto_schema import ServerToolDtoSchema
from .sse_transport_config import SseTransportConfig
from .sse_transport_config_output import SseTransportConfigOutput
from .stdio_transport_config import StdioTransportConfig
from .stdio_transport_config_output import StdioTransportConfigOutput
from .stdio_transport_config_output_transport import StdioTransportConfigOutputTransport
from .team_claim_mapping import TeamClaimMapping
from .team_invitation import TeamInvitation
from .team_member import TeamMember
from .team_with_member_count import TeamWithMemberCount
from .tenant_dto import TenantDto
from .tenant_oidc_configuration import TenantOidcConfiguration
from .tenant_oidc_configuration_client_auth_method import TenantOidcConfigurationClientAuthMethod
from .tenant_saml_configuration import TenantSamlConfiguration
from .test_secret_request import TestSecretRequest
from .test_secret_response import TestSecretResponse
from .update_personal_access_token_request import UpdatePersonalAccessTokenRequest
from .update_server_request import UpdateServerRequest
from .update_server_request_oauth_client_configuration_type_0 import UpdateServerRequestOauthClientConfigurationType0
from .update_server_request_oauth_client_configuration_type_0_grant_type import (
    UpdateServerRequestOauthClientConfigurationType0GrantType,
)
from .update_server_request_oauth_metadata_type_0 import UpdateServerRequestOauthMetadataType0
from .update_server_request_oauth_metadata_type_0_as_type_0 import UpdateServerRequestOauthMetadataType0AsType0
from .update_server_request_oauth_metadata_type_0_resource_type_0 import (
    UpdateServerRequestOauthMetadataType0ResourceType0,
)
from .update_server_request_transport_config_type_4 import UpdateServerRequestTransportConfigType4
from .update_user_me_request import UpdateUserMeRequest
from .update_user_request import UpdateUserRequest
from .upload_source_code_response import UploadSourceCodeResponse
from .user import User
from .user_identity import UserIdentity
from .user_identity_type import UserIdentityType
from .user_small_dto import UserSmallDto

__all__ = (
    "AuditLogResponse",
    "AuthMetadata",
    "AuthMetadataQuota",
    "AuthMetadataQuotaEnabledServers",
    "AuthMetadataTenant",
    "AuthMetadataTenantAbilities",
    "AuthMetadataUser",
    "AwsSecretsManagerConfiguration",
    "AwsSecretsManagerConfigurationOutput",
    "AzureKeyVaultConfiguration",
    "AzureKeyVaultConfigurationOutput",
    "CreatePersonalAccessTokenRequest",
    "CreateSandboxResponse",
    "CreateServerRequest",
    "CreateServerRequestTransportType",
    "CreateUserRequest",
    "DeleteMcpServersServerSlugCredentialsResponse200",
    "DeleteMcpServersServerSlugMembersMemberTypeMemberIdResponse200",
    "DeleteProfilesProfileIdClaimMappingsMappingIdResponse200",
    "DeleteProfilesProfileIdResponse200",
    "DeleteSandboxesSandboxIdResponse200",
    "DeleteTeamsTeamIdClaimMappingsMappingIdResponse200",
    "DeleteTeamsTeamIdInvitationsInvitationIdResponse200",
    "DeleteTeamsTeamIdMembersUserIdResponse200",
    "DeleteTeamsTeamIdResponse200",
    "DeleteUsersUserSubPersonalAccessTokensPatIdResponse200",
    "DeleteUsersUserSubResponse200",
    "ExecCommandBody",
    "GcpSecretManagerConfiguration",
    "GcpSecretManagerConfigurationOutput",
    "GetMcpServersResponse200",
    "GetMcpServersResponse200ServersItem",
    "GetMcpServersResponse200ServersItemUsage",
    "GetMcpServersServerSlugCredentialsAuthorizeUrlRedirect",
    "GetMcpServersServerSlugCredentialsAuthorizeUrlResponse200",
    "GetMcpServersServerSlugCredentialsAuthorizeUrlResponse200Method",
    "GetMcpServersServerSlugCredentialsAuthorizeUrlReturnTo",
    "GetMcpServersServerSlugCredentialsProfileProfileIdApikeysResponse200",
    "GetMcpServersServerSlugCredentialsProfileResponse200",
    "GetMcpServersServerSlugCredentialsResponse200",
    "GetMcpServersServerSlugCredentialsServerApikeysResponse200",
    "GetMcpServersServerSlugCredentialsServerResponse200",
    "GetMcpServersServerSlugCredentialsUserApikeysResponse200",
    "GetMcpServersServerSlugCredentialsUserResponse200",
    "GetMcpServersServerSlugFilesResponse200",
    "GetMcpServersServerSlugOauthDiscoverResponse200",
    "GetMcpServersServerSlugToolsResponse200",
    "GetMembersResponse",
    "GetMembersResponseTeamsItem",
    "GetMembersResponseUsersItem",
    "GetProfilesProfileIdClaimMappingsResponse200",
    "GetProfilesProfileIdResponse200",
    "GetProfilesProfileIdToolsResponse200",
    "GetProfilesProfileIdToolsResponse200Tools",
    "GetProfilesResponse200",
    "GetSandboxIdAuditLogsIdResponse200",
    "GetSandboxIdAuditLogsIdResponse200Pagination",
    "GetSandboxResponse",
    "GetSubscriptionResponse",
    "GetSubscriptionResponseSubscriptionType0",
    "GetSubscriptionResponseSubscriptionType0CardType0",
    "GetTeamsResponse200",
    "GetTeamsTeamIdClaimMappingsResponse200",
    "GetTeamsTeamIdInvitationsResponse200",
    "GetTeamsTeamIdMembersResponse200",
    "GetTeamsTeamIdMembersResponse200MembersItem",
    "GetTeamsTeamIdServersResponse200",
    "GetTeamsTeamIdServersResponse200PermissionsItem",
    "GetTenantsTenantIdResponse200",
    "GetUserMeResponse",
    "GetUserMeResponseUser",
    "GetUsersResponse200",
    "GetUsersType",
    "GetUsersUserSubPersonalAccessTokensResponse200",
    "HashiCorpVaultConfiguration",
    "HashiCorpVaultConfigurationOutput",
    "HostedTransportConfig",
    "HostedTransportConfigOutput",
    "HostedTransportConfigOutputRuntime",
    "HttpStreamingTransportConfig",
    "HttpStreamingTransportConfigOutput",
    "InfisicalConfiguration",
    "InfisicalConfigurationOutput",
    "ListSandboxesResponse",
    "McpAuditLogVerbosity",
    "PatchSecretStoresIdBody",
    "PatchSecretStoresStoreIdMappingsMappingNameBody",
    "PatchUsersUserSubPersonalAccessTokensPatIdResponse200",
    "PersonalAccessToken",
    "PostMcpServersServerSlugCredentialsCopyResponse200",
    "PostMcpServersServerSlugFilesResponse200",
    "PostMcpServersServerSlugToolsToolNameCallBody",
    "PostMcpServersServerSlugToolsToolNameCallBodyArgs",
    "PostProfilesBody",
    "PostProfilesProfileIdClaimMappingsBody",
    "PostProfilesProfileIdClaimMappingsResponse200",
    "PostProfilesResponse200",
    "PostSandboxesSandboxIdWriteFileResponse200",
    "PostSecretStoresBody",
    "PostSecretStoresBodyType",
    "PostSecretStoresStoreIdMappingsBody",
    "PostTeamsBody",
    "PostTeamsTeamIdClaimMappingsBody",
    "PostTeamsTeamIdClaimMappingsResponse200",
    "PostTeamsTeamIdInvitationsBody",
    "PostTeamsTeamIdInvitationsResponse200",
    "PostTeamsTeamIdMembersBody",
    "PostTeamsTeamIdMembersResponse200",
    "PostUsersUserSubPersonalAccessTokensResponse200",
    "Profile",
    "ProfileClaimMapping",
    "ProfileDetailsDto",
    "ProfileDetailsDtoServersItem",
    "PutMcpServersServerSlugAuthorizationBody",
    "PutMcpServersServerSlugConfigBodyType0",
    "PutMcpServersServerSlugConfigBodyType1",
    "PutMcpServersServerSlugConfigBodyType2",
    "PutMcpServersServerSlugConfigBodyType3",
    "PutMcpServersServerSlugConfigBodyType4",
    "PutMcpServersServerSlugCredentialsProfilesProfileIdResponse200",
    "PutMcpServersServerSlugCredentialsServerResponse200",
    "PutMcpServersServerSlugCredentialsUserResponse200",
    "PutMcpServersServerSlugFilesFileIdNameBody",
    "PutMcpServersServerSlugFilesFileIdNameResponse200",
    "PutMcpServersServerSlugFilesFileIdResponse200",
    "PutMcpServersServerSlugIsEnabledBody",
    "PutMcpServersServerSlugIsEnabledResponse200",
    "PutMcpServersServerSlugMembersMemberTypeMemberIdBody",
    "PutMcpServersServerSlugMembersMemberTypeMemberIdBodyRole",
    "PutMcpServersServerSlugMembersMemberTypeMemberIdResponse200",
    "PutMcpServersServerSlugSourceCodeBody",
    "PutProfilesProfileIdBody",
    "PutProfilesProfileIdResponse200",
    "PutProfilesProfileIdServersServerSlugToolsBody",
    "PutProfilesProfileIdServersServerSlugToolsResponse200",
    "PutTeamsTeamIdBody",
    "PutTeamsTeamIdMembersUserIdBody",
    "PutTeamsTeamIdMembersUserIdResponse200",
    "PutUsersMeResponse200",
    "SandboxAuditLog",
    "SandboxAuditLogDetails",
    "SandboxDto",
    "SandboxWithStatusDto",
    "SandboxWithStatusDtoStatus",
    "Schema0",
    "Schema11",
    "Schema17",
    "Schema25",
    "Schema29",
    "Schema32",
    "Schema35",
    "Schema4",
    "Schema40",
    "Schema50",
    "Schema57Type3",
    "Schema64",
    "Schema65",
    "Schema66",
    "Schema67",
    "Schema68",
    "Schema69",
    "Schema76",
    "SecretMappingListResponse",
    "SecretMappingResponse",
    "SecretStoreDetailResponse",
    "SecretStoreListResponse",
    "SecretStoreResponse",
    "SendVerificationCodeRequest",
    "SendVerificationCodeRequestPurpose",
    "SendVerificationCodeResponse",
    "Server",
    "ServerAuthorization",
    "ServerAuthorizationOutput",
    "ServerAuthorizationOutputMethod",
    "ServerCredentialsApiKeys",
    "ServerCredentialsDto",
    "ServerCredentialsDtoType",
    "ServerCredentialsOuth",
    "ServerCredentialsOuthTokenSet",
    "ServerDto",
    "ServerFile",
    "ServerMemberType0",
    "ServerMemberType1",
    "ServerOAuthClientConfiguration",
    "ServerOAuthClientConfigurationGrantType",
    "ServerOAuthMetadata",
    "ServerOAuthMetadataAs",
    "ServerOAuthMetadataResource",
    "ServerPodStatus",
    "ServerRunningStatusResponse",
    "ServerToolDto",
    "ServerToolDtoAnnotationsType0",
    "ServerToolDtoOutputSchemaType0",
    "ServerToolDtoSchema",
    "SseTransportConfig",
    "SseTransportConfigOutput",
    "StdioTransportConfig",
    "StdioTransportConfigOutput",
    "StdioTransportConfigOutputTransport",
    "TeamClaimMapping",
    "TeamInvitation",
    "TeamMember",
    "TeamWithMemberCount",
    "TenantDto",
    "TenantOidcConfiguration",
    "TenantOidcConfigurationClientAuthMethod",
    "TenantSamlConfiguration",
    "TestSecretRequest",
    "TestSecretResponse",
    "UpdatePersonalAccessTokenRequest",
    "UpdateServerRequest",
    "UpdateServerRequestOauthClientConfigurationType0",
    "UpdateServerRequestOauthClientConfigurationType0GrantType",
    "UpdateServerRequestOauthMetadataType0",
    "UpdateServerRequestOauthMetadataType0AsType0",
    "UpdateServerRequestOauthMetadataType0ResourceType0",
    "UpdateServerRequestTransportConfigType4",
    "UpdateUserMeRequest",
    "UpdateUserRequest",
    "UploadSourceCodeResponse",
    "User",
    "UserIdentity",
    "UserIdentityType",
    "UserSmallDto",
)
